import type { ApolloError } from '@apollo/client/errors';
import type { ComputedRef, Ref } from 'vue';
import type { DocumentNode } from 'graphql/language/ast';
import type { TypedDocumentNode } from '@graphql-typed-document-node/core';
import type { QueryRepoQuery, CreateRepoMutation, Exact, CreateRepositoryInput, CommitRepoMutation, CommitRepositoryInput, RecoverRepoMutation, RecoverRepositoryInput, QueryAllQuery, RollbackRepoMutation, RollbackRepositoryInput, RepositoryFieldsFragment, HistoryFieldsFragment, DeltaFieldsFragment } from '../__generated__/graphql';
import type { UseQueryReturn, UseMutationReturn, UseQueryOptions } from '@vue/apollo-composable';
import type { MaybeRefOrGetter } from '@vueuse/core';
import type { NormalizedCacheObject, OperationVariables, ApolloQueryResult, FetchResult, ApolloClient } from '@apollo/client/core';
import type { HistoryTreeNode } from './types';
export * from './types';
export interface AnyVersionOptions {
    endpoint: string;
}
export declare const useAnyVersion: (options: AnyVersionOptions) => {
    apolloClient: ApolloClient<NormalizedCacheObject>;
    options: AnyVersionOptions;
    queries: {
        useQueryRepository: () => UseQueryReturn<QueryRepoQuery, Record<string, never>>;
    };
    mutations: {
        useCreateRepository: () => UseMutationReturn<CreateRepoMutation, Exact<{
            input: CreateRepositoryInput;
        }>>;
        useCommitRepository: () => UseMutationReturn<CommitRepoMutation, Exact<{
            input: CommitRepositoryInput;
        }>>;
        useRecoverRepository: () => UseMutationReturn<RecoverRepoMutation, Exact<{
            input: RecoverRepositoryInput;
        }>>;
    };
};
export declare const useProvideAnyVersion: () => {
    documents: {
        queries: {
            QueryAllDocument: TypedDocumentNode<QueryAllQuery, Exact<{
                [key: string]: never;
            }>>;
            QueryRepoDocument: TypedDocumentNode<QueryRepoQuery, Exact<{
                repoId: string;
            }>>;
        };
        mutations: {
            CreateRepoDocument: TypedDocumentNode<CreateRepoMutation, Exact<{
                input: CreateRepositoryInput;
            }>>;
            CommitRepoDocument: TypedDocumentNode<CommitRepoMutation, Exact<{
                input: CommitRepositoryInput;
            }>>;
            RollbackRepoDocument: TypedDocumentNode<RollbackRepoMutation, Exact<{
                input: RollbackRepositoryInput;
            }>>;
        };
    };
    queries: {
        useQueryRepository: () => UseQueryReturn<QueryRepoQuery, Record<string, never>>;
    };
    mutations: {
        useCreateRepository: () => UseMutationReturn<CreateRepoMutation, Exact<{
            input: CreateRepositoryInput;
        }>>;
        useCommitRepository: () => UseMutationReturn<CommitRepoMutation, Exact<{
            input: CommitRepositoryInput;
        }>>;
        useRecoverRepository: () => UseMutationReturn<RecoverRepoMutation, Exact<{
            input: RecoverRepositoryInput;
        }>>;
    };
}, useInjectAnyVersion: () => {
    documents: {
        queries: {
            QueryAllDocument: TypedDocumentNode<QueryAllQuery, Exact<{
                [key: string]: never;
            }>>;
            QueryRepoDocument: TypedDocumentNode<QueryRepoQuery, Exact<{
                repoId: string;
            }>>;
        };
        mutations: {
            CreateRepoDocument: TypedDocumentNode<CreateRepoMutation, Exact<{
                input: CreateRepositoryInput;
            }>>;
            CommitRepoDocument: TypedDocumentNode<CommitRepoMutation, Exact<{
                input: CommitRepositoryInput;
            }>>;
            RollbackRepoDocument: TypedDocumentNode<RollbackRepoMutation, Exact<{
                input: RollbackRepositoryInput;
            }>>;
        };
    };
    queries: {
        useQueryRepository: () => UseQueryReturn<QueryRepoQuery, Record<string, never>>;
    };
    mutations: {
        useCreateRepository: () => UseMutationReturn<CreateRepoMutation, Exact<{
            input: CreateRepositoryInput;
        }>>;
        useCommitRepository: () => UseMutationReturn<CommitRepoMutation, Exact<{
            input: CommitRepositoryInput;
        }>>;
        useRecoverRepository: () => UseMutationReturn<RecoverRepoMutation, Exact<{
            input: RecoverRepositoryInput;
        }>>;
    };
} | undefined;
export declare function useAnyVersionStore(maybeRepoId: MaybeRefOrGetter<string>, lazy?: boolean): {
    load: (document?: DocumentNode | null | undefined, variables?: {
        repoId: string;
    } | null | undefined, options?: UseQueryOptions<any, OperationVariables> | null | undefined) => boolean;
    current: ComputedRef<HistoryTreeNode | null | undefined>;
    fileName: ComputedRef<string>;
    root: ComputedRef<HistoryTreeNode | undefined>;
    flattens: ComputedRef<readonly HistoryTreeNode[] | undefined>;
    repository: ComputedRef<RepositoryFieldsFragment | null | undefined>;
    histories: ComputedRef<readonly HistoryFieldsFragment[] | null | undefined>;
    deltas: ComputedRef<readonly DeltaFieldsFragment[] | null | undefined>;
    loading: Ref<boolean>;
    error: Ref<ApolloError | null>;
    queries: {
        refetch: (variables?: {
            repoId: string;
        } | undefined) => Promise<ApolloQueryResult<QueryRepoQuery>> | undefined;
    };
    mutations: {
        commit: (message?: string) => Promise<void>;
        recover: (target: HistoryTreeNode) => Promise<FetchResult<RecoverRepoMutation, Record<string, any>, Record<string, any>> | null>;
        rollback: (target: HistoryTreeNode) => Promise<void>;
        prune: (target: HistoryTreeNode) => Promise<void>;
        uncover: (target: HistoryTreeNode) => Promise<void>;
    };
};
